@@ -224,8 +224,9 @@ parser.add_option(
     default=None,
     help="""\
 If using Python3.3 or Python3.4, provide the path of a Python binary to use
-for Scons. Otherwise Nuitka can use what you run Nuitka with or a "scons"
-binary that is found in PATH, or a Python installation from Windows registry.""",
+for Scons. Otherwise Nuitka can use what you run Nuitka with or a Python
+installation from Windows registry. On Windows Python 3.5 or higher is
+needed. On non-Windows, Python 2.6 or 2.7 will do as well.""",
 )
 
 warnings_group = OptionGroup(parser, "Control the warnings to be given by Nuitka")
