@@ -381,13 +381,14 @@ def executePostProcessing():
 @echo off
 rem This script was created by Nuitka to execute '%(exe_filename)s' with Python DLL being found.
 set PATH=%(dll_directory)s;%%PATH%%
-set PYTHONHOME=%(dll_directory)s
+set PYTHONHOME=%(python_home)s
 %(debugger_call)s"%%~dp0.\\%(exe_filename)s" %%*
 """ % {
             "debugger_call": (" ".join(wrapCommandForDebuggerForExec()) + " ")
             if Options.shallRunInDebugger()
             else "",
             "dll_directory": dll_directory,
+            "python_home": sys.prefix,
             "exe_filename": os.path.basename(result_filename),
         }
 
