@@ -29,6 +29,7 @@ from .Checkers import checkStatementsSequenceOrNone
 from .ExpressionBases import ExpressionChildrenHavingBase
 from .NodeBases import StatementChildrenHavingBase
 from .NodeMakingHelpers import (
+    makeConstantReplacementNode,
     makeStatementExpressionOnlyReplacementNode,
     wrapExpressionWithNodeSideEffects,
     wrapStatementWithSideEffects,
@@ -38,7 +39,37 @@ from .shapes.BuiltinTypeShapes import tshape_bool, tshape_unknown
 from .StatementNodes import StatementsSequence
 
 
-class ExpressionConditional(ExpressionChildrenHavingBase):
+class ConditionalValueComputeMixin(object):
+    __slots__ = ()
+
+    def _computeConditionTruthValue(self, trace_collection):
+        condition = self.subnode_condition
+
+        truth_value, message = condition.computeExpressionBool(trace_collection)
+        if truth_value is not None:
+            assert type(truth_value) is bool, truth_value
+
+            new_condition = wrapExpressionWithNodeSideEffects(
+                new_node=makeConstantReplacementNode(
+                    constant=truth_value, node=condition, user_provided=False
+                ),
+                old_node=condition,
+            )
+
+            self.replaceChild(condition, new_condition)
+
+            trace_collection.signalChange(
+                tags="new_constant", source_ref=self.source_ref, message=message
+            )
+
+            return truth_value, new_condition
+        else:
+            # Query the truth value after the expression is evaluated, once it is
+            # evaluated in onExpression, it is known.
+            return condition.getTruthValue(), condition
+
+
+class ExpressionConditional(ConditionalValueComputeMixin, ExpressionChildrenHavingBase):
     kind = "EXPRESSION_CONDITIONAL"
 
     named_children = ("condition", "expression_yes", "expression_no")
@@ -90,11 +121,7 @@ branches.""",
 
         # Tell it we are evaluation it for boolean value only, it may demote
         # itself possibly.
-        condition.computeExpressionBool(trace_collection)
-        condition = self.subnode_condition
-
-        # Decide this based on truth value of condition.
-        truth_value = condition.getTruthValue()
+        truth_value, condition = self._computeConditionTruthValue(trace_collection)
 
         # TODO: We now know that condition evaluates to true for the yes branch
         # and to not true for no branch, the branch should know that.
@@ -113,7 +140,7 @@ branches.""",
             yes_branch = self.subnode_expression_yes
 
             # If it's aborting, it doesn't contribute to merging.
-            if yes_branch.willRaiseException(BaseException):
+            if truth_value is not True and yes_branch.willRaiseException(BaseException):
                 branch_yes_collection = None
         else:
             branch_yes_collection = None
@@ -132,7 +159,7 @@ branches.""",
             no_branch = self.subnode_expression_no
 
             # If it's aborting, it doesn't contribute to merging.
-            if no_branch.willRaiseException(BaseException):
+            if truth_value is not False and no_branch.willRaiseException(BaseException):
                 branch_no_collection = None
         else:
             branch_no_collection = None
@@ -416,7 +443,7 @@ Convert conditional 'and' expression with unused result into conditional stateme
         )
 
 
-class StatementConditional(StatementChildrenHavingBase):
+class StatementConditional(ConditionalValueComputeMixin, StatementChildrenHavingBase):
     kind = "STATEMENT_CONDITIONAL"
 
     named_children = ("condition", "yes_branch", "no_branch")
@@ -521,12 +548,7 @@ branches.""",
 
         # Tell it we are evaluation it for boolean value only, it may demote
         # itself possibly.
-        condition.computeExpressionBool(trace_collection)
-        condition = self.subnode_condition
-
-        # Query the truth value after the expression is evaluated, once it is
-        # evaluated in onExpression, it is known.
-        truth_value = condition.getTruthValue()
+        truth_value, condition = self._computeConditionTruthValue(trace_collection)
 
         # TODO: We now know that condition evaluates to true for the yes branch
         # and to not true for no branch, the branch collection should know that.
@@ -756,7 +778,7 @@ Empty 'yes' branch for conditional statement treated with inverted condition che
 def makeNotExpression(expression):
     # These are invertible with bool type shape.
     if expression.isExpressionComparison() and expression.getTypeShape() is tshape_bool:
-        return expression.makeInverseComparision()
+        return expression.makeInverseComparison()
     else:
         return ExpressionOperationNot(
             operand=expression, source_ref=expression.getSourceReference()
