@@ -1,4 +1,4 @@
-#     Copyright 2021, Jorj McKie, mailto:<jorj.x.mckie@outlook.de>
+#     Copyright 2022, Jorj McKie, mailto:<jorj.x.mckie@outlook.de>
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -69,20 +69,12 @@ class NuitkaPluginNumpy(NuitkaPluginBase):
     """
 
     plugin_name = "numpy"  # Nuitka knows us by this name
-    plugin_desc = "Required for numpy, scipy, pandas, etc."
+    plugin_desc = "Required for numpy."
 
-    def __init__(self, include_matplotlib, include_scipy):
+    def __init__(self, include_scipy):
         self.include_numpy = True  # For consistency
         self.include_scipy = include_scipy
 
-        # Information about matplotlib install.
-        self.matplotlib_info = None
-
-        if include_matplotlib:
-            self.warning(
-                "The option '--noinclude-matplotlib' is deprecated, matplotlib as its own plugin now."
-            )
-
     @classmethod
     def isRelevant(cls):
         """Check whether plugin might be required.
@@ -103,17 +95,6 @@ class NuitkaPluginNumpy(NuitkaPluginBase):
 Should scipy, sklearn or skimage when used be not included with numpy, Default is %default.""",
         )
 
-        # TODO: This is deprecated, remove it eventually.
-        from optparse import SUPPRESS_HELP
-
-        group.add_option(
-            "--noinclude-matplotlib",
-            action="store_true",
-            dest="include_matplotlib",
-            default=False,
-            help=SUPPRESS_HELP,
-        )
-
     def getExtraDlls(self, module):
         """Copy extra shared libraries or data for this installation.
 
@@ -219,7 +200,7 @@ Should scipy, sklearn or skimage when used be not included with numpy, Default i
                             "scipy", dll_dir_name, source_filename
                         )
 
-    def onModuleEncounter(self, module_filename, module_name, module_kind):
+    def onModuleEncounter(self, module_name, module_filename, module_kind):
         if not self.include_scipy and module_name.hasOneOfNamespaces(
             "scipy", "sklearn", "skimage"
         ):
@@ -231,14 +212,6 @@ Should scipy, sklearn or skimage when used be not included with numpy, Default i
         if self.include_scipy and module_name in sklearn_mods:
             return True, "Needed by sklearn"
 
-    # TODO: This should be done with anti-bloat, but it's not yet on by default
-    # and this is for a hotfix.
-    def onModuleSourceCode(self, module_name, source_code):
-        if module_name == "numpy.core.overrides":
-            source_code = source_code.replace("public_api.__code__ = ", "")
-
-        return source_code
-
 
 class NuitkaPluginDetectorNumpy(NuitkaPluginBase):
     """Only used if plugin is NOT activated.
@@ -269,13 +242,5 @@ class NuitkaPluginDetectorNumpy(NuitkaPluginBase):
             None
         """
         module_name = module.getFullName()
-        if module_name.hasOneOfNamespaces(
-            "numpy", "scipy", "skimage", "pandas", "sklearn"
-        ):
-            self.warnUnusedPlugin(
-                "Numpy support for at least '%s'."
-                % module_name.getTopLevelPackageName()
-            )
-
-
-# TODO: Move to its own file
+        if module_name == "numpy":
+            self.warnUnusedPlugin("Numpy may miss DLLs otherwise.")
