@@ -1,4 +1,4 @@
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,10 +29,7 @@ from nuitka.nodes.CallNodes import makeExpressionCall
 from nuitka.nodes.CodeObjectSpecs import CodeObjectSpec
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.ContainerMakingNodes import makeExpressionMakeTupleOrConstant
-from nuitka.nodes.DictionaryNodes import (
-    ExpressionKeyValuePair,
-    makeExpressionMakeDict,
-)
+from nuitka.nodes.DictionaryNodes import makeExpressionMakeDict
 from nuitka.nodes.ExceptionNodes import StatementReraiseException
 from nuitka.nodes.FrameNodes import (
     StatementsFrameAsyncgen,
@@ -41,6 +38,9 @@ from nuitka.nodes.FrameNodes import (
     StatementsFrameGenerator,
     StatementsFrameModule,
 )
+from nuitka.nodes.KeyValuePairNodes import (
+    makeKeyValuePairExpressionsFromKwArgs,
+)
 from nuitka.nodes.NodeBases import NodeBase
 from nuitka.nodes.NodeMakingHelpers import mergeStatements
 from nuitka.nodes.StatementNodes import StatementsSequence
@@ -60,7 +60,7 @@ def extractDocFromBody(node):
     body = node.body
     doc = None
 
-    # Work around ast.get_docstring breakage.
+    # Work around "ast.get_docstring" breakage.
     if body and getKind(body[0]) == "Expr":
         if getKind(body[0].value) == "Str":  # python3.7 or earlier
             doc = body[0].value.s
@@ -342,7 +342,7 @@ def buildNode(provider, node, source_ref, allow_none=False):
         raise
     except:
         optimization_logger.warning(
-            "Problem at '%s' with %s." % (source_ref, ast.dump(node))
+            "Problem at '%s' with %s." % (source_ref.getAsString(), ast.dump(node))
         )
         raise
 
@@ -413,7 +413,7 @@ def buildAnnotationNode(provider, node, source_ref):
 def makeModuleFrame(module, statements, source_ref):
     assert module.isCompiledPythonModule()
 
-    if Options.is_fullcompat:
+    if Options.is_full_compat:
         code_name = "<module>"
     else:
         if module.isMainModule():
@@ -523,7 +523,8 @@ def makeStatementsSequence(statements, allow_none, source_ref):
 
     if statements:
         return StatementsSequence(
-            statements=mergeStatements(statements), source_ref=source_ref
+            statements=mergeStatements(statements, allow_none=allow_none),
+            source_ref=source_ref,
         )
     else:
         return None
@@ -574,18 +575,7 @@ def makeDictCreationOrConstant2(keys, values, source_ref):
         )
     else:
         result = makeExpressionMakeDict(
-            pairs=[
-                ExpressionKeyValuePair(
-                    key=makeConstantRefNode(
-                        constant=key,
-                        source_ref=value.getSourceReference(),
-                        user_provided=True,
-                    ),
-                    value=value,
-                    source_ref=value.getSourceReference(),
-                )
-                for key, value in zip(keys, values)
-            ],
+            pairs=makeKeyValuePairExpressionsFromKwArgs(zip(keys, values)),
             source_ref=source_ref,
         )
 
